@@ -8,7 +8,7 @@ use URI::QueryParam;
 use Carp;
 use Moo;
 use namespace::clean;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 
 $Net::DNS::Lite::CACHE = Cache::LRU->new( size => 512 );
@@ -91,7 +91,8 @@ sub venue {
 sub artist_setlists {
     my $self = shift;
     my $mbid = shift;
-    return $self->request("artist/$mbid/setlists.json");
+    my $query_param = shift;
+    return $self->request("artist/$mbid/setlists.json", $query_param);
 } 
 
 sub setlist_lastfm {
